/**********************************************************************
 *  Clock Face widget implementation.
 **********************************************************************
 *   Copyright (C) 2019 by AK-47
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 * This file is part of mx-datetime.
 **********************************************************************/

#ifndef CLOCKFACE_H
#define CLOCKFACE_H

#include <QWidget>
#include <QTime>

class ClockFace : public QWidget
{
    Q_OBJECT
public:
    ClockFace(QWidget *parent = nullptr);
    void setTime(QTime newtime);

private:
    QTime time;
    void paintEvent(QPaintEvent *event);
};

#endif // CLOCKFACE_H
